@@ -2,7 +2,7 @@
 /*
  * mh.h -- main header file for all of nmh
  *
- * $Id: mh.h,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
+ * $Id: mh.h,v 1.2 2000/01/26 05:03:07 danh Exp $
  */
 
 #include <h/nmh.h>
@@ -39,6 +39,12 @@ struct node {
 
 struct swit {
     char *sw;
+
+    /* The minchars field is apparently used like this:
+
+       -# : Switch can be abbreviated to # characters; switch hidden in -help.
+       0  : Switch can't be abbreviated;               switch shown in -help.
+       #  : Switch can be abbreviated to # characters; switch shown in -help. */
     int minchars;
 };
 
