@@ -2,7 +2,7 @@
 /*
  * discard.c -- discard output on a file pointer
  *
- * $Id$
+ * $Id: discard.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
  */
 
 #include <h/mh.h>
@@ -43,10 +43,10 @@ discard (FILE *io)
     tcflush (fileno(io), TCOFLUSH);
 #else
 # ifdef HAVE_TERMIO_H
-    if (ioctl (fileno(io), TCGETA, &tio) != NOTOK)
+    if (ioctl (fileno(io), TCGETA, &tio) != -1)
 	ioctl (fileno(io), TCSETA, &tio);
 # else
-    if (ioctl (fileno(io), TIOCGETP, (char *) &tio) != NOTOK)
+    if (ioctl (fileno(io), TIOCGETP, (char *) &tio) != -1)
 	ioctl (fileno(io), TIOCSETP, (char *) &tio);
 # endif
 #endif
