@@ -2,7 +2,7 @@
 /*
  * picksbr.c -- routines to help pick along...
  *
- * $Id: picksbr.c,v 1.3 1999/09/12 13:50:12 doug Exp $
+ * $Id: picksbr.c,v 1.5 2000/01/26 21:35:43 danh Exp $
  */
 
 #include <h/mh.h>
@@ -690,7 +690,7 @@ plist
 	if (*p2 == CCHR) {
 	    c = p2[1];
 	    do {
-		if (*p1 == c || cc[*p1] == c)
+		if (*p1 == c || cc[(unsigned char)*p1] == c)
 		    if (advance (p1, p2))
 			return 1;
 	    } while (*p1++);
@@ -715,7 +715,7 @@ advance (char *alp, char *aep)
     for (;;)
 	switch (*ep++) {
 	    case CCHR: 
-		if (*ep++ == *lp++ || ep[-1] == cc[lp[-1]])
+		if (*ep++ == *lp++ || ep[-1] == cc[(unsigned char)lp[-1]])
 		    continue;
 		return 0;
 
@@ -754,7 +754,7 @@ advance (char *alp, char *aep)
 
 	    case CCHR | STAR: 
 		curlp = lp;
-		while (*lp++ == *ep || cc[lp[-1]] == *ep)
+		while (*lp++ == *ep || cc[(unsigned char)lp[-1]] == *ep)
 		    continue;
 		ep++;
 		goto star;
