@@ -2,7 +2,7 @@
 /*
  * slocal.c -- asynchronously filter and deliver new mail
  *
- * $Id: slocal.c,v 1.4 1999/09/12 13:50:12 doug Exp $
+ * $Id: slocal.c,v 1.7 2000/02/04 20:28:24 danh Exp $
  */
 
 /*
@@ -28,7 +28,15 @@
 #include <signal.h>
 #include <sys/ioctl.h>
 #include <fcntl.h>
-#include <grp.h>
+
+#include <grp.h>     /* initgroups() is here on Solaris 2.6 */
+#include <unistd.h>  /* initgroups() is here on HP-UX 10.20 */
+
+/* On AIX 4.1, initgroups() is defined and even documented (giving the parameter
+   types as "char*" and "int"), but doesn't have a prototype in any of the
+   system header files.  On other OSes, this should be a duplicate prototype
+   that won't cause any errors or warnings. */
+extern int  initgroups(const char*, gid_t);
 
 #ifdef HAVE_DB1_NDBM_H
 #include <db1/ndbm.h>
@@ -76,7 +84,7 @@ static struct swit switches[] = {
 #define VERSIONSW     13
     { "version", 0 },
 #define	HELPSW        14
-    { "help", 4 },
+    { "help", 0 },
     { NULL, 0 }
 };
 
