@@ -2,7 +2,7 @@
 /*
  * client.c -- connect to a server
  *
- * $Id: client.c,v 1.3 1999/10/15 22:38:56 doug Exp $
+ * $Id: client.c,v 1.5 2000/02/04 01:32:12 danh Exp $
  */
 
 #include <h/mh.h>
@@ -92,8 +92,7 @@ client (char *args, char *protocol, char *service, int rproto,
     char *arguments[MAXARGS];
     register struct hostent *hp;
     register struct servent *sp;
-/* we assume netent and getnetbyaddr come with gethostbyname */
-#ifdef	HAVE_GETHOSTBYNAME
+#ifndef	HAVE_GETHOSTBYNAME
     register struct netent *np;
 #endif
 
@@ -209,6 +208,7 @@ rcaux (struct servent *sp, struct hostent *hp, int rproto,
 
 #ifdef KPOP
     int rem;
+    struct hostent *hp2;
 #endif	/* KPOP */
 
     for (ap = nets; ap < n1; ap++)
@@ -257,7 +257,11 @@ rcaux (struct servent *sp, struct hostent *hp, int rproto,
     if (kservice) {	/* "pop" */
 	char *instance;
 
-	if ((instance = strdup (hp->h_name)) == NULL) {
+	if (( hp2 = gethostbyaddr( hp->h_addr, hp->h_length, hp->h_addrtype ))
+		== NULL ) {
+	    return NOTOK;
+	}
+	if ((instance = strdup (hp2->h_name)) == NULL) {
 	    close (sd);
 	    strncpy (response, "Out of memory.", len_response);
 	    return OOPS2;
