@@ -2,9 +2,10 @@
 /*
  * mts.c -- definitions for the mail transport system
  *
- * $Id: mts.c,v 1.2 1999/10/15 22:38:56 doug Exp $
+ * $Id: mts.c,v 1.4 2000/01/26 04:54:30 danh Exp $
  */
 
+#include "h/mh.h"   /* for snprintf() */
 #include <h/nmh.h>
 
 #define nmhetcdir(file) NMHETCDIR#file
@@ -60,7 +61,7 @@ static char username[BUFSIZ];
 static char fullname[BUFSIZ];
 
 /* variables for username masquerading */
-static int MMailids = 0;
+int MMailids = 0;  /* used from post.c as well as here */
 static char *mmailid = "0";
 
 
@@ -374,7 +375,8 @@ getfullname (void)
 
 /*
  * Find the user's username and full name, and cache them.
- * It also handles mmailid processing (username masquerading)
+ * Also, handle "mmailid" username masquerading controlled from the GECOS field
+ * of the passwd file. 
  */
 
 static void
@@ -409,9 +411,13 @@ getuserinfo (void)
 
     /*
      * Do mmailid (username masquerading) processing.  The GECOS
-     * field should have the form "Full Name <fakeusername>".
+     * field should have the form "Full Name <fakeusername>".  For instance,
+     * "Dan Harkless <Dan.Harkless>".  Naturally, you'll want your MTA to have
+     * an alias (e.g. in /etc/aliases) from "fakeusername" to your account name.
      */
 #ifndef	GCOS_HACK
+    /* What is this code here for?  As of 2000-01-25, GCOS_HACK doesn't appear
+       anywhere else in nmh.  -- Dan Harkless <dan-nmh@dilvish.speed.net> */
     for (cp = fullname; *np && *np != (MMailids ? '<' : ','); *cp++ = *np++)
 	continue;
 #else
